package app24.imagesearcher;

import java.io.File;
import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicInteger;
import javax.swing.DefaultListModel;
import javax.swing.SwingUtilities;

public class ImageSearchTask implements Runnable {
    private File searchDir;
    private Executor executor;
    private DefaultListModel listModel;
    private AtomicInteger fileCounter;

    public ImageSearchTask(File searchDir, Executor executor, DefaultListModel listModel,
            AtomicInteger fileCounter) {
        this.searchDir = searchDir;
        this.executor = executor;
        this.listModel = listModel;
        this.fileCounter = fileCounter;
    }

    @Override
    public void run() {
        if (fileCounter.get() > ImageSearcher.MAX_RESULT) {
            return;
        }
        File[] children = searchDir.listFiles();
        if (children == null) {
            return;
        }
        for (final File child : children) {
            if (child.isDirectory()) {
                executor.execute(new ImageSearchTask(child, executor, listModel, fileCounter));
            } else if (child.isFile()) {
                String name = child.getName().toLowerCase();
                if (name.endsWith(".jpg")) {
                    final int fileNumber = fileCounter.getAndIncrement();
                    if (fileNumber > ImageSearcher.MAX_RESULT) {
                        break;
                    }

                    SwingUtilities.invokeLater(new Runnable() {
                        public void run() {
                            listModel.addElement(fileNumber + ": " +
                                    child.getAbsolutePath());
                        }
                    });

                }
            }
        }
    }
}